@@ -5,8 +5,7 @@ from social_auth.utils import setting
 PIPELINE_ENTRY = 'social_auth.backends.pipeline.misc.save_status_to_session'
 
 
-def save_status_to_session(request, backend, details, response, uid,
-                           *args, **kwargs):
+def save_status_to_session(request, auth, *args, **kwargs):
     """Saves current social-auth status to session."""
     next_entry = setting('SOCIAL_AUTH_PIPELINE_RESUME_ENTRY')
 
@@ -18,13 +17,8 @@ def save_status_to_session(request, backend, details, response, uid,
     except ValueError:
         idx = None
 
+    data = auth.to_session_dict(idx, *args, **kwargs)
+
     name = setting('SOCIAL_AUTH_PARTIAL_PIPELINE_KEY', 'partial_pipeline')
-    request.session[name] = {
-        'backend': backend.name,
-        'uid': uid,
-        'details': details,
-        'response': response,
-        'is_new': kwargs.get('is_new', True),
-        'next_index': idx
-    }
+    request.session[name] = data
     request.session.modified = True
